==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-listTile.dart <==
/*
Description:
A widget that dynamically creates a tile view using List Tiles for a list of incoming data.
The widget accepts a title, subtitle, leading widget that can be an image or an icon.
There is also the option to add top and bottom text on the right hand side of the image. 

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-listTileWithImage.dart';

Usage:
- The widget returns the index value and the title of a tapped tile using the callback function.

- Defining the widget objects and parameters 
    List<TileData> listData = [
      TileData(
          leading: Icon(Icons.search),
          title: 'Search',
          subtitle: 'Search Bar',
          enabled: true,
          selected: true),
      TileData(
          leading: Icon(Icons.home),
          title: 'Home',
          subtitle: 'Home Button',
          enabled: true,
          selected: false),
      TileData(
          leading: Icon(Icons.alarm),
          title: 'Clock',
          subtitle: 'Set Alarms',
          enabled: true,
          selected: false)
    ];
    ListTileParameters tileParameters = new ListTileParameters(dense: true, isThreeLine: true);

    onListTapped(int index, String title) {
      print(index);
      print(title);
    }

- Calling the widget object
    CustomListTileGeneric(listData, tileParameters, onListTapped);
    
Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'consts.dart' as consts;
import 'widget-classesUsed.dart';
import 'package:quiver/iterables.dart';

Widget CustomListTileGeneric(List<TileData> listTileData,
    ListTileParameters listTileParams, Function(int, String) callback) {
  if (listTileData == null ||
      listTileData.length == 0 ||
      listTileParams == null) {
    return Column(
      children: <Widget>[
        ListTile(
          trailing: Icon(consts.icon1),
          title: Text(consts.listTitle),
          subtitle: Text(consts.listSubtitle),
          leading: Icon(consts.icon1),
        ),
        ListTile(
          trailing: Icon(consts.icon1),
          title: Text(consts.listTitle),
          subtitle: Text(consts.listSubtitle),
          leading: Icon(consts.icon1),
        )
      ],
    );
  } else {
    return SingleChildScrollView(
        child: Column(
            children: enumerate(listTileData)
                .map((key) => (ListTile(
                      leading: key.value.leading,
                      title: Text(key.value.title),
                      subtitle: Text(key.value.subtitle),
                      trailing: key.value.trailing,
                      isThreeLine: (listTileParams.isThreeLine != null)
                          ? listTileParams.isThreeLine
                          : false,
                      dense: (listTileParams.dense != null)
                          ? listTileParams.dense
                          : false,
                      onTap: () {
                        return callback(key.index, key.value.title);
                      },
                      onLongPress: () {
                        return callback(key.index, key.value.title);
                      },
                      enabled: (key.value.enabled != null)
                          ? key.value.enabled
                          : true,
                      selected: (key.value.selected != null)
                          ? key.value.selected
                          : false,
                    )))
                .toList()));
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-listTile.dart <==
/*
Description:
A widget that dynamically creates a tile view using List Tiles for a list of incoming data.
The widget accepts a title, subtitle, leading widget that can be an image or an icon.
There is also the option to add top and bottom text on the right hand side of the image. 

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-listTileWithImage.dart';

Usage:
- The widget returns the index value and the title of a tapped tile using the callback function.

- Defining the widget objects and parameters 
    List<TileData> listData = [
      TileData(
          leading: Icon(Icons.search),
          title: 'Search',
          subtitle: 'Search Bar',
          enabled: true,
          selected: true),
      TileData(
          leading: Icon(Icons.home),
          title: 'Home',
          subtitle: 'Home Button',
          enabled: true,
          selected: false),
      TileData(
          leading: Icon(Icons.alarm),
          title: 'Clock',
          subtitle: 'Set Alarms',
          enabled: true,
          selected: false)
    ];
    ListTileParameters tileParameters = new ListTileParameters(dense: true, isThreeLine: true);

    onListTapped(int index, String title) {
      print(index);
      print(title);
    }

- Calling the widget object
    customListTileGeneric(listData, tileParameters, onListTapped);
    
Author:
Rishabh Thakur
*/

import 'package:flutter/material.dart';
import 'consts.dart' as consts;
import 'widget-classesUsed.dart';
import 'package:quiver/iterables.dart';

Widget customListTileGeneric(List<TileData> listTileData,
    ListTileParameters listTileparams, Function(int, String) callback) {
  if (listTileData == null ||
      listTileData.length == 0 ||
      listTileparams == null) {
    return Column(
      children: <Widget>[
        ListTile(
          trailing: Icon(consts.icon1),
          title: Text(consts.listTitle),
          subtitle: Text(consts.listSubtitle),
          leading: Icon(consts.icon1),
        ),
        ListTile(
          trailing: Icon(consts.icon1),
          title: Text(consts.listTitle),
          subtitle: Text(consts.listSubtitle),
          leading: Icon(consts.icon1),
        )
      ],
    );
  } else {
    return SingleChildScrollView(
        child: Column(
            children: enumerate(listTileData)
                .map((key) => (ListTile(
                      leading: key.value.leading,
                      title: Text(key.value.title),
                      subtitle: Text(key.value.subtitle),
                      trailing: key.value.trailing,
                      isThreeLine: (listTileparams.isThreeLine != null)
                          ? listTileparams.isThreeLine
                          : false,
                      dense: (listTileparams.dense != null)
                          ? listTileparams.dense
                          : false,
                      onTap: () {
                        return callback(key.index, key.value.title);
                      },
                      onLongPress: () {
                        return callback(key.index, key.value.title);
                      },
                      enabled: (key.value.enabled != null)
                          ? key.value.enabled
                          : true,
                      selected: (key.value.selected != null)
                          ? key.value.selected
                          : false,
                    )))
                .toList()));
  }
}
